# Asciirt - Python Module

With Asciirt, you can create cool ascii art with only one line of code!

# How to use

```python
import asciirt

asciirt.pacman()
```

# List of art

`asciirt.pacman()`<br>
`asciirt.amogus()`<br>
`asciirt.babymogus()`<br>
`asciirt.macintosh()`<br>
`asciirt.atari()`<br>
`asciirt.keyboard()`<br>
`asciirt.mouse()`<br>

# Result

![Asciirt Result](https://i.imgur.com/Tzoo0O0.png)
